@@ -1084,41 +1084,45 @@ def ExportCoverage(collection, *args, **kwargs):
 
         # get catalog id
 
-        url = HOST + "/core/api/catalogue/1.0/catalogues"
+        try :
 
-        payload = {}
-        headers = {
-            'API-Key': Api_Key
-        }
+            url = HOST + "/core/api/catalogue/1.0/catalogues"
 
-        response = requests.request("GET", url, headers=headers, data=payload)
+            payload = {}
+            headers = {
+                'API-Key': Api_Key
+            }
 
-        res_json = response.json()
-        # print(res_json['context']['matched'])
+            response = requests.request("GET", url, headers=headers, data=payload)
 
-        matched = res_json['context']['matched'] + 1
+            res_json = response.json()
+            # print(res_json['context']['matched'])
 
-        url = HOST + "/core/api/catalogue/1.0/catalogues?limit=" + str(matched)
+            matched = res_json['context']['matched'] + 1
 
-        payload = {}
-        headers = {
-            'API-Key': Api_Key
-        }
+            url = HOST + "/core/api/catalogue/1.0/catalogues?limit=" + str(matched)
 
-        response = requests.request("GET", url, headers=headers, data=payload)
+            payload = {}
+            headers = {
+                'API-Key': Api_Key
+            }
 
-        res_json = response.json()
-        # print(res_json['catalogues'])
+            response = requests.request("GET", url, headers=headers, data=payload)
 
-        crt = len(res_json['catalogues'])
+            res_json = response.json()
+            # print(res_json['catalogues'])
 
-        arr = []
-        for i in range(0, crt):
+            crt = len(res_json['catalogues'])
 
-            data = res_json['catalogues'][i]['stac_id']
-            if data == 'THEOS1':
-                data2 = res_json['catalogues'][i]['id']
-                arr.append(data2)
+            arr = []
+            for i in range(0, crt):
+
+                data = res_json['catalogues'][i]['stac_id']
+                if data == satellite :
+                    data2 = res_json['catalogues'][i]['id']
+                    arr.append(data2)
+        except :
+            pass
 
         if satellite != False:
 
@@ -1351,7 +1355,7 @@ def CreateCoverage(parameter, *args, **kwargs):
             os.remove(zip_id + ".zip")
 
         if status == "successful":
-            return 'successful : ' + HOST + "/management/studio/coverages/" + collection
+            return 'successful : ' + HOST + "/management/datastore/coverage/" + collection
 
         else:
             return 'error to create coverage : failed'
@@ -1523,7 +1527,7 @@ def CreateCoverageTile(parameter, *args, **kwargs):
                 break
 
         if status == "successful":
-            return 'successful : ' + HOST + "/management/studio/tiles-coverage/" + collection_out
+            return 'successful : ' + HOST + "/management/visual/tiles/coverage/" + collection_out
 
         else:
             return 'error to create coverage : failed'
