@@ -357,7 +357,7 @@ def getImport(dataset_id, data,  VallarisServer, Api_Key):
 
         if not os.path.exists(dir):
             shutil.rmtree(dir)
-        return 'successful : ' + VallarisServer + '/management/studio/features/' + dataset_id
+        return 'successful : ' + VallarisServer + '/management/datastore/features/' + dataset_id
 
     except Exception as e:
         # print(e)
@@ -465,7 +465,7 @@ def makeTile(dataset_id, dataset_out, VallarisServer, Api_Key, parameter):
                 break
         
         if status == "successful":
-            return 'successful : ' + VallarisServer + "/management/studio/tiles/" + parameter['data_filter']['dataset_out']
+            return 'successful : ' + VallarisServer + "/management/visual/tiles/vector/" + parameter['data_filter']['dataset_out']
         
         else:
             return 'error to create coverage : failed'
